@@ -264,7 +264,7 @@ class Item(BaseItem):
         params: Mapping | None = None,
         request_kwargs: Mapping | None = None,
     ) -> bool:
-        """Get a list of completed catalog tasks for the item.
+        """Check if there is any pending task for the item.
 
         :param params: Params to send with your request.
 
@@ -598,7 +598,12 @@ class Item(BaseItem):
                  return_responses: bool = False,
                  no_change_timestamp: bool = False,
                  ignore_history_dir: bool = False,
-                 params: Mapping | None = None) -> list[Request | Response]:
+                 source: str | list[str] | None = None,
+                 exclude_source: str | list[str] | None = None,
+                 stdout: bool = False,
+                 params: Mapping | None = None,
+                 timeout: int | float | tuple[int, float] | None = None
+                 ) -> list[Request | Response]:
         """Download files from an item.
 
         :param files: Only download files matching given file names.
@@ -646,6 +651,12 @@ class Item(BaseItem):
                                     current time instead of changing it to that given in
                                     the original archive.
 
+        :param source: Filter files based on their source value in files.xml
+                       (i.e. `original`, `derivative`, `metadata`).
+
+        :param exclude_source: Filter files based on their source value in files.xml
+                               (i.e. `original`, `derivative`, `metadata`).
+
         :param params: URL parameters to send with
                        download request (e.g. `cnt=0`).
 
@@ -664,6 +675,17 @@ class Item(BaseItem):
         no_change_timestamp = bool(no_change_timestamp)
         ignore_history_dir = bool(ignore_history_dir)
         params = params or None
+        if source:
+            if not isinstance(source, list):
+                source = [source]
+        if exclude_source:
+            if not isinstance(exclude_source, list):
+                exclude_source = [exclude_source]
+        if stdout:
+            fileobj = os.fdopen(sys.stdout.fileno(), "wb", closefd=False)
+            verbose = False
+        else:
+            fileobj = None
 
         if not dry_run:
             if item_index and verbose:
@@ -696,6 +718,8 @@ class Item(BaseItem):
                 exclude_pattern=exclude_pattern,
                 on_the_fly=on_the_fly
             )
+        if stdout:
+            files = list(files)  # type: ignore
 
         errors = []
         downloaded = 0
@@ -706,6 +730,10 @@ class Item(BaseItem):
             if ignore_history_dir is True:
                 if f.name.startswith('history/'):
                     continue
+            if source and not any(f.source == x for x in source):
+                continue
+            if exclude_source and any(f.source == x for x in exclude_source):
+                continue
             file_count += 1
             if no_directory:
                 path = f.name
@@ -714,9 +742,13 @@ class Item(BaseItem):
             if dry_run:
                 print(f.url)
                 continue
+            if stdout and file_count < len(files):  # type: ignore
+                ors = True
+            else:
+                ors = False
             r = f.download(path, verbose, ignore_existing, checksum, destdir,
-                           retries, ignore_errors, None, return_responses,
-                           no_change_timestamp, params)
+                           retries, ignore_errors, fileobj, return_responses,
+                           no_change_timestamp, params, None, stdout, ors, timeout)
             if return_responses:
                 responses.append(r)
 
@@ -739,6 +771,7 @@ class Item(BaseItem):
                         target: str | None = None,
                         append: bool = False,
                         append_list: bool = False,
+                        insert: bool = False,
                         priority: int = 0,
                         access_key: str | None = None,
                         secret_key: str | None = None,
@@ -797,7 +830,8 @@ class Item(BaseItem):
             access_key=access_key,
             secret_key=secret_key,
             append=append,
-            append_list=append_list)
+            append_list=append_list,
+            insert=insert)
         # Must use Session.prepare_request to make sure session settings
         # are used on request!
         prepared_request = request.prepare()
